@@ -566,7 +566,7 @@ init_text()         /* Setup constant strings. */
     STRNCPY(v->con_names[0], _("Kilometer-to-mile conversion factor"),
             MAXLINE - 1);
     STRNCPY(v->con_names[1], _("square root of 2"), MAXLINE - 1);
-    STRNCPY(v->con_names[2], _("e"), MAXLINE - 1);
+    STRNCPY(v->con_names[2], _("Euler's Number (e)"), MAXLINE - 1);
     STRNCPY(v->con_names[3], _("pi"), MAXLINE - 1);
     STRNCPY(v->con_names[4], _("Centimeter-to-inch conversion factor"),
             MAXLINE - 1);
@@ -600,6 +600,11 @@ getparam(char *s, char *argv[], char *errmes)
     if (*argv != NULL && argv[0][0] != '-') {
         STRNCPY(s, *argv, MAXLINE - 1);
     } else { 
+        /* Translators: the following string contains two strings that
+         * are passed to it: the first is the gcalctool program name and
+         * the second is an error message (see the last parameter in the 
+         * getparam() call in the get_options() routine below.
+         */
         FPRINTF(stderr, _("%s: %s as next argument.\n"), v->progname, errmes);
         exit(1);                        
     }                                  
@@ -609,6 +614,10 @@ getparam(char *s, char *argv[], char *errmes)
 void
 usage(char *progname)
 {
+    /* Translators: the following string contains two strings that
+     * are passed to it: the first is the gcalctool program name and
+     * the second is the program version number.
+     */
     FPRINTF(stderr, _("%s version %s\n\n"), progname, VERSION);
     FPRINTF(stderr, _("Usage: %s: [-D] [-E] [-a accuracy] "), progname);
     FPRINTF(stderr, _("\t\t [-?] [-v] [-h]\n"));
@@ -645,14 +654,6 @@ get_options(int argc, char *argv[])      /* Extract command line options. */
                         v->accuracy = DEFAULT_ACCURACY;
                     }
                     break;
-                
-                case 'n' :
-                    if (strcmp(argv[0], "-name") == 0)
-                    {
-                        INC;
-                        read_str(&v->appname, argv[0]);
-                    }
-                    break;
 
                 case '?' :
                 case 'v' : 
@@ -727,6 +728,7 @@ int
 main(int argc, char **argv)
 {
     char *ptr;
+    struct exprm_state *e;
     
     v = (Vars)  LINT_CAST(calloc(1, sizeof(struct calcVars)));
 
@@ -735,11 +737,10 @@ main(int argc, char **argv)
     textdomain(GETTEXT_PACKAGE);
 
     v->progname = argv[0];     /* Save programs name. */
-    v->appname  = NULL;
     if ((ptr = strrchr(argv[0], '/')) != NULL) {
-        read_str(&v->appname, ptr+1);
+        v->appname = strdup(ptr+1);
     } else {
-        read_str(&v->appname, argv[0]);
+        v->appname = strdup(argv[0]);
     }
     
     init_state();
@@ -762,7 +763,6 @@ main(int argc, char **argv)
     show_display(v->MPdisp_val);     /* Output in correct display mode. */
 
     memset(&(v->h), 0, sizeof(struct exprm_state_history)); /* clear expression mode state history*/
-    struct exprm_state *e;
     e = get_state();
     e->clear = 1;              /* Clear initial state as if clear was pressed */
     
