@@ -42,10 +42,8 @@
 #define MKSTEMP      (void) mkstemp
 #define REWIND       (void) rewind
 #define SNPRINTF     (void) snprintf
-#define SPRINTF      (void) sprintf
 #define SSCANF       (void) sscanf
 #define STRCAT       (void) strcat
-#define STRCPY       (void) strcpy
 #define STRNCPY      (void) strncpy
 #define STRNCAT      (void) strncat
 #define UNLINK       (void) unlink
