@@ -207,12 +207,12 @@ static struct button_widget button_widgets[] = {
     { GDK_equal, GDK_KP_Enter, GDK_Return, GDK_equal,      0 }},
 
     {KEY_START_BLOCK,        "start_group",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_parenleft, 0 }},
+    { 0,             GDK_SHIFT_MASK, 0 },
+    { GDK_parenleft, GDK_parenleft,  0 }},
 
     {KEY_END_BLOCK,          "end_group",
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_parenright, 0 }},
+    { 0,              GDK_SHIFT_MASK, 0 },
+    { GDK_parenright, GDK_parenright, 0 }},
 
     {KEY_ADD,                "add",
     { GDK_SHIFT_MASK, 0,        0,          0 },
@@ -223,8 +223,8 @@ static struct button_widget button_widgets[] = {
     { GDK_minus, GDK_KP_Subtract, GDK_R4, 0 }},
 
     {KEY_MULTIPLY,           "multiply",
-    { GDK_SHIFT_MASK, 0,               0,      0 },
-    { GDK_asterisk,   GDK_KP_Multiply, GDK_R6, 0 }},
+    { 0,            GDK_SHIFT_MASK, 0,               0,      0 },
+    { GDK_asterisk, GDK_asterisk,   GDK_KP_Multiply, GDK_R6, 0 }},
 
     {KEY_DIVIDE,             "divide",
     { 0,         GDK_SHIFT_MASK, 0,             0,      GDK_SHIFT_MASK, 0 },
@@ -724,7 +724,7 @@ static char *
 make_hostname()
 {
     Display *dpy = GDK_DISPLAY();
-    char client_hostname[MAXHOSTNAMELEN + 4];
+    char client_hostname[MAXLINE] = "";
     char hostname[MAXHOSTNAMELEN];
     char *display = DisplayString(dpy);
     char *scanner = display;
@@ -745,10 +745,8 @@ make_hostname()
         strcmp(display, "localhost") &&     
         strcmp(display, "unix") &&          
         strcmp(display, "")) {              
-        SPRINTF(client_hostname, " [%s] ", hostname);
-    } else {                                
-        STRCPY(client_hostname, "");        
-    }                                       
+        SNPRINTF(client_hostname, MAXLINE, " [%s] ", hostname);
+    }
 
     *scanner = ':';
     
@@ -887,7 +885,7 @@ set_bit_panel()
 {
     int bit_str_len, i, MP1[MP_SIZE], MP2[MP_SIZE];
     int MP[MP_SIZE];
-    char *bit_str, label[3], tmp[MAXLINE];
+    char *bit_str, label[MAXLINE], tmp[MAXLINE];
 
     switch (v->syntax) {
         case NPA:
@@ -902,9 +900,12 @@ set_bit_panel()
                 if (bit_str_len <= MAXBITS) {
                     gtk_widget_set_sensitive(X->bit_panel, TRUE);
 
-                    STRCPY(label, " 0");
                     for (i = 0; i < MAXBITS; i++) {
-                        label[1] = (i < bit_str_len) ? bit_str[bit_str_len-i-1] : '0';
+                        if (i < bit_str_len) {
+                            SNPRINTF(label, MAXLINE, " %c", bit_str[bit_str_len-i-1]);
+                        } else {
+                            SNPRINTF(label, MAXLINE, " 0");
+                        }
                         gtk_label_set_text(GTK_LABEL(X->bits[MAXBITS - i - 1]), label);
                     }
 
@@ -916,20 +917,23 @@ set_bit_panel()
 
           case EXPRS: 
               {
+                  char *bit_str, label[3], tmp[MAXLINE];
                   int ret = usable_num(MP);
                   if (ret || !is_integer(MP)) {
                       gtk_widget_set_sensitive(X->bit_panel, FALSE);
                       return;
                   }
-                  char *bit_str, label[3], tmp[MAXLINE];
                   bit_str = make_fixed(MP, tmp, BIN, MAXLINE, FALSE);
                   bit_str_len = strlen(bit_str);
                   if (bit_str_len <= MAXBITS) {
                       gtk_widget_set_sensitive(X->bit_panel, TRUE);
                       
-                      STRCPY(label, " 0");
                       for (i = 0; i < MAXBITS; i++) {
-                          label[1] = (i < bit_str_len) ? bit_str[bit_str_len-i-1] : '0';
+                          if (i < bit_str_len) {
+                              SNPRINTF(label, MAXLINE, " %c", bit_str[bit_str_len-i-1]);
+                          } else {
+                              SNPRINTF(label, MAXLINE, " 0");
+                          }
                           gtk_label_set_text(GTK_LABEL(X->bits[MAXBITS - i - 1]), label);
                       }
                   } else {
@@ -971,7 +975,7 @@ ui_set_display(char *str, int cursor)
         str = " ";
     } else {
         if (v->noparens == 0) {
-            localize_number(localized, str);
+            localize_number(localized, str, MAX_LOCALIZED);
             str = localized;
         }
     }
@@ -2850,7 +2854,7 @@ read_cfdefs()        /* Read constant/function definitions. */
         get_constant(n);
     }
     for (n = 0; n < MAX_FUNCTIONS; n++) {
-        STRCPY(v->fun_vals[n], "");    /* Initially empty function strings. */
+        STRNCPY(v->fun_vals[n], "", MAXLINE - 1);    /* Initially empty function strings. */
         get_function(n);
     }
 }
