@@ -1,7 +1,7 @@
 
 /*  $Header$
  *
- *  Copyright (c) 1987-2007 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
  *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -1212,7 +1212,7 @@ L10:
     v->dtype = FIX;
     v->accuracy = MAX_DIGITS;
     mpcmf(&x[1], tmp);
-    STRCPY(disp, make_number(tmp, v->base, FALSE));
+    STRNCPY(disp, make_number(tmp, v->base, FALSE), MAXLINE - 1);
 
     if (disp[0] == '1') {
         y[ll+1]++;
